function [T_alpha] = DTsallis_kNN_k_estimation(X,Y,co)
%Estimates the Tsallis divergence (T_alpha) of X and Y (X(:,t), Y(:,t) is the t^th sample)
%using the kNN method (S={k}). The number of samples in X [=size(X,2)] and Y [=size(Y,2)] can be different. Cost parameters are provided in the cost object co.
%
%We make use of the naming convention 'D<name>_estimation', to ease embedding new divergence estimation methods.
%
%REFERENCE: 
%   Barnabs Pczos, Zoltn Szab, Jeff Schneider: Nonparametric divergence estimators for Independent Subspace Analysis. EUSIPCO-2011, pages 1849-1853.
%   Barnabs Pczos, Jeff Schneider: On the Estimation of alpha-Divergences. AISTATS-2011, pages 609-617.
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

%co.mult:OK.

if size(X,1)~=size(Y,1)
    disp('Error: the dimension of X and Y must be equal.');
end

D_alpha = estimate_Dalpha(X,Y,co);
T_alpha = (D_alpha-1)/(co.alpha-1);
