function [H_alpha] = HRenyi_GSF_estimation(Y,co)
%Estimates the Rnyi entropy (H_alpha) of Y (Y(:,t) is the t^th sample)
%using the GSF method. Cost parameters are provided in the cost object co.
%
%We make use of the naming convention 'H<name>_estimation', to ease embedding new entropy estimation methods.
%
%REFERENCE: 
%   Barnabs Pczos, Andrs Lrincz. Independent Subspace Analysis Using Geodesic Spanning Trees. ICML-2005, pages 673-680.
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

[d,num_of_samples] = size(Y);

%compute kNN graph (S={1,...,k}):
    [squared_distances,I] = kNN_squared_distances(Y,Y,co,1);%I:int32
    
%kNN relations -> weighted kNN graph (W):
    J = repmat(int32([1:num_of_samples]),co.k,1);%double->int32
    D = squared_distances(:).^(d*(1-co.alpha));
    W = spalloc(num_of_samples,num_of_samples,2*num_of_samples*co.k);
    W(I+(J-1)*num_of_samples) = D;
    W(J+(I-1)*num_of_samples) = D;

%W->L (using MatlabBGL); minimal spanning forest, and its weight (L): 
    L = compute_MST(W,co.GSFmethod);

%H_alpha estimation:
    H_alpha = log(L/num_of_samples.^co.alpha) / (1-co.alpha);
