function [H_alpha] = HRenyi_kNN_k_estimation(Y,co)
%Estimates the Rnyi entropy (H_alpha) of Y (Y(:,t) is the t^th sample)
%using the kNN method (S={k}). Cost parameters are provided in the cost object co.
%
%We make use of the naming convention 'H<name>_estimation', to ease embedding new entropy estimation methods.
%
%REFERENCE: 
%   Nikolai Leonenko, Luc Pronzato, and Vippal Savani. A class of Rnyi information estimators for multidimensional densities. Annals of Statistics, 36(5):21532182, 2008.
%   Joseph E. Yukich. Probability Theory of Classical Euclidean Optimization Problems, Lecture Notes in Mathematics, 1998, vol. 1675.
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

[d,num_of_samples] = size(Y);
squared_distances = kNN_squared_distances(Y,Y,co,1);

%co.mult:OK.
	
%H_alpha estimation:
	V = pi^(d/2)*gamma(d/2+1);
	C = ( gamma(co.k)/gamma(co.k+1-co.alpha) )^(1/(1-co.alpha));
    s = sum( squared_distances(co.k,:).^(d*(1-co.alpha)/2) ); %'/2' <= squared distances
	H_alpha = log( (num_of_samples-1) / num_of_samples * V^(1-co.alpha) * C^(1-co.alpha) * s / (num_of_samples-1)^(co.alpha) ) / (1-co.alpha);

