function [co] = IRenyi_DRenyi_initialization(mult)
%Initialization of the "meta" Rnyi mutual information estimator, which is 
%   1)based on an(y) estimator for Rnyi  divergence,
%   2)is treated as a cost object (co). 
%Mutual information is estimated using the relation: I(y^1,...,y^M) = D(f_y,\prod_{m=1}^M f_{y^m}).
%
%Here, we make use of the naming convention: 'I<name>_initialization', to ease embedding new mutual information estimation methods.
%
%INPUT:
%   mult: is a multiplicative constant relevant (needed) in the estimation; '=1' means yes, '=0' no.
%OUTPUT:
%   co: object (structure).
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

%mandatory fields:
    co.name = 'Renyi_DRenyi';
    co.mul = mult;
    co.alpha = 0.95;
	
%other fields:    
    co.member_name = 'Renyi_kNN_k'; %you can change it to any Rnyi divergence estimator
    co.member_co = D_initialization(co.member_name,mult);
    co.member_co.alpha = co.alpha;