function [e_hat,W_hat,de_hat,s_hat] = estimate_fAR_IPA(x,L,ICA_method,opt_type,cost_type,cost_name,unknown_dimensions,de,fARmethod_parameters)
%Estimates the fAR-IPA model. Method: fAR identification + ISA on the estimated innovation.
%
%INPUT:
%   x: x(:,t) is the t^th observation from the fAR model.
%   L: fAR order.
%   ICA_method: the name of the ICA method applied, see 'estimate_ICA.m'.
%   cost_type, cost_name, opt_type: cost type, cost name, optimization  type. Example: cost_type = 'sumH', cost_name = 'Renyi_kNN_1tok', opt_type = 'greedy' means that we use an entropy sum ISA formulation ('sumH'), where the entropies are estimated Rnyi entropies via kNN methods ('Renyi_kNN_1tok') and the optimization is greedy; see also 'demo_ISA.m'
%   unknown_dimensions: '0' means 'the subspace dimensions are known'; '1' means 'the number of the subspaces are known' (but the individual dimensions are unknown).
%   de: 
%       1)in case of 'unknown_dimensions = 0': 'de' contains the subspace dimensions.
%       2)in case of 'unknown_dimensions = 1': the length of 'de' must be equal to the number of subspaces, but the coordinates of the vector can be arbitrary.
%   fARmethod_parameters: parameters of the fAR estimator, see 'estimate_fAR.m'.
%OUTPUT:
%   e_hat: e_hat(:,t) is the estimated driving noise at time t.
%   W_hat: estimated demixing matrix.
%   de_hat: in case of known subspace dimensions ('unknown_dimensions = 0') de_hat = de; else it contains the estimated subspace dimensions; ordered increasingly.
%   s_hat: s_hat(:,t) is the estimated source at time t.
%REFERENCE:
%  Zoltn Szab and Barnabs Pczos. Nonparametric Independent Process Analysis. European Signal Processing Conference (EUSIPCO), pages 1718-1722, 2011.
%
%Copyright (C) 2012 Zoltan Szabo ("http://nipg.inf.elte.hu/szzoli", "szzoli (at) cs (dot) elte (dot) hu")
%
%This file is part of the ITE (Information Theoretical Estimators) Matlab/Octave toolbox.
%
%ITE is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
%
%This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
%
%You should have received a copy of the GNU General Public License along with ITE. If not, see <http://www.gnu.org/licenses/>.

%fAR identification, estimated innovation (x_innovation_hat):
    x_innovation_hat = estimate_fAR(x,L,fARmethod_parameters);
    
%ISA on the estimated innovation:    
    [e_hat,W_hat,de_hat] = estimate_ISA(x_innovation_hat,ICA_method,opt_type,cost_type,cost_name,unknown_dimensions,de,size(x_innovation_hat,1));
    
%estimated source (s_hat):    
    s_hat = W_hat * x;    